
'Generated protocol buffer code.'
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xla/python/tpu_driver/tpu_driver.proto', package='tpu_driver', syntax='proto2', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n:tensorflow/compiler/xla/python/tpu_driver/tpu_driver.proto\x12\ntpu_driver"1\n\x0eChipCoordinate\x12\t\n\x01x\x18\x01 \x02(\x05\x12\t\n\x01y\x18\x02 \x02(\x05\x12\t\n\x01z\x18\x03 \x02(\x05"\x8d\x01\n\x0bTpuCoreInfo\x12\n\n\x02id\x18\x01 \x02(\x05\x12\x1a\n\x12core_on_chip_index\x18\x02 \x01(\x05\x12\x1a\n\x12core_on_host_index\x18\x03 \x01(\x05\x12\x1b\n\x13hbm_bytes_available\x18d \x01(\x03\x12\x1d\n\x15hbm_bytes_allocatable\x18e \x01(\x03"u\n\x0bTpuChipInfo\x12%\n\x04core\x18\x01 \x03(\x0b2\x17.tpu_driver.TpuCoreInfo\x12\x0f\n\x07host_id\x18\x02 \x01(\x05\x12.\n\nchip_coord\x18\x03 \x01(\x0b2\x1a.tpu_driver.ChipCoordinate"u\n\x07CpuInfo\x12\x15\n\rnum_cpu_cores\x18\x01 \x02(\x05\x12\x1d\n\x15cpu_load_average_1min\x18\x02 \x02(\x02\x12\x17\n\x0fram_bytes_total\x18d \x02(\x03\x12\x1b\n\x13ram_bytes_available\x18e \x02(\x03"\xd3\x01\n\nSystemInfo\x12)\n\x08tpu_chip\x18\x01 \x03(\x0b2\x17.tpu_driver.TpuChipInfo\x12 \n\x03cpu\x18\x02 \x02(\x0b2\x13.tpu_driver.CpuInfo\x12+\n\nlocal_core\x18\x03 \x03(\x0b2\x17.tpu_driver.TpuCoreInfo\x12\x0f\n\x07host_id\x18\x04 \x01(\x05\x12\x12\n\nhost_count\x18\x05 \x01(\x05\x12\x12\n\nchip_count\x18\x06 \x01(\x05\x12\x12\n\ncore_count\x18\x07 \x01(\x05"\xae\x01\n\x0fTpuDriverConfig\x12\x0e\n\x06worker\x18\x01 \x01(\t\x124\n\x04grpc\x18\x02 \x01(\x0b2&.tpu_driver.TpuDriverConfig.GrpcConfig\x1aU\n\nGrpcConfig\x12#\n\x17connection_timeout_secs\x18\x01 \x01(\x03:\x0230\x12"\n\x16keepalive_timeout_secs\x18\x02 \x01(\x03:\x0230*\x17\n\x0cMemoryRegion\x12\x07\n\x03HBM\x10\x01')
_MEMORYREGION = _descriptor.EnumDescriptor(name='MemoryRegion', full_name='tpu_driver.MemoryRegion', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='HBM', index=0, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=898, serialized_end=921)
_sym_db.RegisterEnumDescriptor(_MEMORYREGION)
MemoryRegion = enum_type_wrapper.EnumTypeWrapper(_MEMORYREGION)
HBM = 1
_CHIPCOORDINATE = _descriptor.Descriptor(name='ChipCoordinate', full_name='tpu_driver.ChipCoordinate', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='x', full_name='tpu_driver.ChipCoordinate.x', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='y', full_name='tpu_driver.ChipCoordinate.y', index=1, number=2, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='z', full_name='tpu_driver.ChipCoordinate.z', index=2, number=3, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=74, serialized_end=123)
_TPUCOREINFO = _descriptor.Descriptor(name='TpuCoreInfo', full_name='tpu_driver.TpuCoreInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='id', full_name='tpu_driver.TpuCoreInfo.id', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_on_chip_index', full_name='tpu_driver.TpuCoreInfo.core_on_chip_index', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_on_host_index', full_name='tpu_driver.TpuCoreInfo.core_on_host_index', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hbm_bytes_available', full_name='tpu_driver.TpuCoreInfo.hbm_bytes_available', index=3, number=100, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hbm_bytes_allocatable', full_name='tpu_driver.TpuCoreInfo.hbm_bytes_allocatable', index=4, number=101, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=126, serialized_end=267)
_TPUCHIPINFO = _descriptor.Descriptor(name='TpuChipInfo', full_name='tpu_driver.TpuChipInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='core', full_name='tpu_driver.TpuChipInfo.core', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_id', full_name='tpu_driver.TpuChipInfo.host_id', index=1, number=2, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='chip_coord', full_name='tpu_driver.TpuChipInfo.chip_coord', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=269, serialized_end=386)
_CPUINFO = _descriptor.Descriptor(name='CpuInfo', full_name='tpu_driver.CpuInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='num_cpu_cores', full_name='tpu_driver.CpuInfo.num_cpu_cores', index=0, number=1, type=5, cpp_type=1, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu_load_average_1min', full_name='tpu_driver.CpuInfo.cpu_load_average_1min', index=1, number=2, type=2, cpp_type=6, label=2, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='ram_bytes_total', full_name='tpu_driver.CpuInfo.ram_bytes_total', index=2, number=100, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='ram_bytes_available', full_name='tpu_driver.CpuInfo.ram_bytes_available', index=3, number=101, type=3, cpp_type=2, label=2, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=388, serialized_end=505)
_SYSTEMINFO = _descriptor.Descriptor(name='SystemInfo', full_name='tpu_driver.SystemInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='tpu_chip', full_name='tpu_driver.SystemInfo.tpu_chip', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu', full_name='tpu_driver.SystemInfo.cpu', index=1, number=2, type=11, cpp_type=10, label=2, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='local_core', full_name='tpu_driver.SystemInfo.local_core', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_id', full_name='tpu_driver.SystemInfo.host_id', index=3, number=4, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_count', full_name='tpu_driver.SystemInfo.host_count', index=4, number=5, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='chip_count', full_name='tpu_driver.SystemInfo.chip_count', index=5, number=6, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='core_count', full_name='tpu_driver.SystemInfo.core_count', index=6, number=7, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=508, serialized_end=719)
_TPUDRIVERCONFIG_GRPCCONFIG = _descriptor.Descriptor(name='GrpcConfig', full_name='tpu_driver.TpuDriverConfig.GrpcConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='connection_timeout_secs', full_name='tpu_driver.TpuDriverConfig.GrpcConfig.connection_timeout_secs', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=True, default_value=30, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='keepalive_timeout_secs', full_name='tpu_driver.TpuDriverConfig.GrpcConfig.keepalive_timeout_secs', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=True, default_value=30, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=811, serialized_end=896)
_TPUDRIVERCONFIG = _descriptor.Descriptor(name='TpuDriverConfig', full_name='tpu_driver.TpuDriverConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='worker', full_name='tpu_driver.TpuDriverConfig.worker', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='grpc', full_name='tpu_driver.TpuDriverConfig.grpc', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_TPUDRIVERCONFIG_GRPCCONFIG], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto2', extension_ranges=[], oneofs=[], serialized_start=722, serialized_end=896)
_TPUCHIPINFO.fields_by_name['core'].message_type = _TPUCOREINFO
_TPUCHIPINFO.fields_by_name['chip_coord'].message_type = _CHIPCOORDINATE
_SYSTEMINFO.fields_by_name['tpu_chip'].message_type = _TPUCHIPINFO
_SYSTEMINFO.fields_by_name['cpu'].message_type = _CPUINFO
_SYSTEMINFO.fields_by_name['local_core'].message_type = _TPUCOREINFO
_TPUDRIVERCONFIG_GRPCCONFIG.containing_type = _TPUDRIVERCONFIG
_TPUDRIVERCONFIG.fields_by_name['grpc'].message_type = _TPUDRIVERCONFIG_GRPCCONFIG
DESCRIPTOR.message_types_by_name['ChipCoordinate'] = _CHIPCOORDINATE
DESCRIPTOR.message_types_by_name['TpuCoreInfo'] = _TPUCOREINFO
DESCRIPTOR.message_types_by_name['TpuChipInfo'] = _TPUCHIPINFO
DESCRIPTOR.message_types_by_name['CpuInfo'] = _CPUINFO
DESCRIPTOR.message_types_by_name['SystemInfo'] = _SYSTEMINFO
DESCRIPTOR.message_types_by_name['TpuDriverConfig'] = _TPUDRIVERCONFIG
DESCRIPTOR.enum_types_by_name['MemoryRegion'] = _MEMORYREGION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
ChipCoordinate = _reflection.GeneratedProtocolMessageType('ChipCoordinate', (_message.Message,), {'DESCRIPTOR': _CHIPCOORDINATE, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(ChipCoordinate)
TpuCoreInfo = _reflection.GeneratedProtocolMessageType('TpuCoreInfo', (_message.Message,), {'DESCRIPTOR': _TPUCOREINFO, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(TpuCoreInfo)
TpuChipInfo = _reflection.GeneratedProtocolMessageType('TpuChipInfo', (_message.Message,), {'DESCRIPTOR': _TPUCHIPINFO, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(TpuChipInfo)
CpuInfo = _reflection.GeneratedProtocolMessageType('CpuInfo', (_message.Message,), {'DESCRIPTOR': _CPUINFO, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(CpuInfo)
SystemInfo = _reflection.GeneratedProtocolMessageType('SystemInfo', (_message.Message,), {'DESCRIPTOR': _SYSTEMINFO, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(SystemInfo)
TpuDriverConfig = _reflection.GeneratedProtocolMessageType('TpuDriverConfig', (_message.Message,), {'GrpcConfig': _reflection.GeneratedProtocolMessageType('GrpcConfig', (_message.Message,), {'DESCRIPTOR': _TPUDRIVERCONFIG_GRPCCONFIG, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'}), 'DESCRIPTOR': _TPUDRIVERCONFIG, '__module__': 'tensorflow.compiler.xla.python.tpu_driver.tpu_driver_pb2'})
_sym_db.RegisterMessage(TpuDriverConfig)
_sym_db.RegisterMessage(TpuDriverConfig.GrpcConfig)




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_shape_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/tfprof_output.proto', package='tensorflow.tfprof', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n,tensorflow/core/profiler/tfprof_output.proto\x12\x11tensorflow.tfprof\x1a,tensorflow/core/framework/tensor_shape.proto\x1a%tensorflow/core/framework/types.proto"v\n\x11TFProfTensorProto\x12#\n\x05dtype\x18\x01 \x01(\x0e2\x14.tensorflow.DataType\x12\x14\n\x0cvalue_double\x18\x02 \x03(\x01\x12\x13\n\x0bvalue_int64\x18\x03 \x03(\x03\x12\x11\n\tvalue_str\x18\x04 \x03(\t"\x8e\x07\n\x0eGraphNodeProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12:\n\x0ctensor_value\x18\x0f \x01(\x0b2$.tensorflow.tfprof.TFProfTensorProto\x12\x11\n\trun_count\x18\x15 \x01(\x03\x12\x13\n\x0bexec_micros\x18\x02 \x01(\x03\x12\x1f\n\x17accelerator_exec_micros\x18\x11 \x01(\x03\x12\x17\n\x0fcpu_exec_micros\x18\x12 \x01(\x03\x12\x17\n\x0frequested_bytes\x18\x03 \x01(\x03\x12\x12\n\npeak_bytes\x18\x18 \x01(\x03\x12\x16\n\x0eresidual_bytes\x18\x19 \x01(\x03\x12\x14\n\x0coutput_bytes\x18\x1a \x01(\x03\x12\x12\n\nparameters\x18\x04 \x01(\x03\x12\x11\n\tfloat_ops\x18\r \x01(\x03\x12\x0f\n\x07devices\x18\n \x03(\t\x12\x1e\n\x16total_definition_count\x18\x17 \x01(\x03\x12\x17\n\x0ftotal_run_count\x18\x16 \x01(\x03\x12\x19\n\x11total_exec_micros\x18\x06 \x01(\x03\x12%\n\x1dtotal_accelerator_exec_micros\x18\x13 \x01(\x03\x12\x1d\n\x15total_cpu_exec_micros\x18\x14 \x01(\x03\x12\x1d\n\x15total_requested_bytes\x18\x07 \x01(\x03\x12\x18\n\x10total_peak_bytes\x18\x1b \x01(\x03\x12\x1c\n\x14total_residual_bytes\x18\x1c \x01(\x03\x12\x1a\n\x12total_output_bytes\x18\x1d \x01(\x03\x12\x18\n\x10total_parameters\x18\x08 \x01(\x03\x12\x17\n\x0ftotal_float_ops\x18\x0e \x01(\x03\x12,\n\x06shapes\x18\x0b \x03(\x0b2\x1c.tensorflow.TensorShapeProto\x12H\n\x0cinput_shapes\x18\x10 \x03(\x0b22.tensorflow.tfprof.GraphNodeProto.InputShapesEntry\x123\n\x08children\x18\x0c \x03(\x0b2!.tensorflow.tfprof.GraphNodeProto\x1aP\n\x10InputShapesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12+\n\x05value\x18\x02 \x01(\x0b2\x1c.tensorflow.TensorShapeProto:\x028\x01"\xed\x04\n\x13MultiGraphNodeProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bexec_micros\x18\x02 \x01(\x03\x12\x1f\n\x17accelerator_exec_micros\x18\x0c \x01(\x03\x12\x17\n\x0fcpu_exec_micros\x18\r \x01(\x03\x12\x17\n\x0frequested_bytes\x18\x03 \x01(\x03\x12\x12\n\npeak_bytes\x18\x10 \x01(\x03\x12\x16\n\x0eresidual_bytes\x18\x11 \x01(\x03\x12\x14\n\x0coutput_bytes\x18\x12 \x01(\x03\x12\x12\n\nparameters\x18\x04 \x01(\x03\x12\x11\n\tfloat_ops\x18\x05 \x01(\x03\x12\x19\n\x11total_exec_micros\x18\x06 \x01(\x03\x12%\n\x1dtotal_accelerator_exec_micros\x18\x0e \x01(\x03\x12\x1d\n\x15total_cpu_exec_micros\x18\x0f \x01(\x03\x12\x1d\n\x15total_requested_bytes\x18\x07 \x01(\x03\x12\x18\n\x10total_peak_bytes\x18\x13 \x01(\x03\x12\x1c\n\x14total_residual_bytes\x18\x14 \x01(\x03\x12\x1a\n\x12total_output_bytes\x18\x15 \x01(\x03\x12\x18\n\x10total_parameters\x18\x08 \x01(\x03\x12\x17\n\x0ftotal_float_ops\x18\t \x01(\x03\x126\n\x0bgraph_nodes\x18\n \x03(\x0b2!.tensorflow.tfprof.GraphNodeProto\x128\n\x08children\x18\x0b \x03(\x0b2&.tensorflow.tfprof.MultiGraphNodeProto"\xc2\x01\n\x0bAdviceProto\x12>\n\x08checkers\x18\x01 \x03(\x0b2,.tensorflow.tfprof.AdviceProto.CheckersEntry\x1aW\n\rCheckersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x125\n\x05value\x18\x02 \x01(\x0b2&.tensorflow.tfprof.AdviceProto.Checker:\x028\x01\x1a\x1a\n\x07Checker\x12\x0f\n\x07reports\x18\x02 \x03(\tb\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_TFPROFTENSORPROTO = _descriptor.Descriptor(name='TFProfTensorProto', full_name='tensorflow.tfprof.TFProfTensorProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='dtype', full_name='tensorflow.tfprof.TFProfTensorProto.dtype', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value_double', full_name='tensorflow.tfprof.TFProfTensorProto.value_double', index=1, number=2, type=1, cpp_type=5, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value_int64', full_name='tensorflow.tfprof.TFProfTensorProto.value_int64', index=2, number=3, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value_str', full_name='tensorflow.tfprof.TFProfTensorProto.value_str', index=3, number=4, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=152, serialized_end=270)
_GRAPHNODEPROTO_INPUTSHAPESENTRY = _descriptor.Descriptor(name='InputShapesEntry', full_name='tensorflow.tfprof.GraphNodeProto.InputShapesEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.tfprof.GraphNodeProto.InputShapesEntry.key', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.tfprof.GraphNodeProto.InputShapesEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1103, serialized_end=1183)
_GRAPHNODEPROTO = _descriptor.Descriptor(name='GraphNodeProto', full_name='tensorflow.tfprof.GraphNodeProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.tfprof.GraphNodeProto.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_value', full_name='tensorflow.tfprof.GraphNodeProto.tensor_value', index=1, number=15, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='run_count', full_name='tensorflow.tfprof.GraphNodeProto.run_count', index=2, number=21, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='exec_micros', full_name='tensorflow.tfprof.GraphNodeProto.exec_micros', index=3, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='accelerator_exec_micros', full_name='tensorflow.tfprof.GraphNodeProto.accelerator_exec_micros', index=4, number=17, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu_exec_micros', full_name='tensorflow.tfprof.GraphNodeProto.cpu_exec_micros', index=5, number=18, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='requested_bytes', full_name='tensorflow.tfprof.GraphNodeProto.requested_bytes', index=6, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_bytes', full_name='tensorflow.tfprof.GraphNodeProto.peak_bytes', index=7, number=24, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='residual_bytes', full_name='tensorflow.tfprof.GraphNodeProto.residual_bytes', index=8, number=25, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_bytes', full_name='tensorflow.tfprof.GraphNodeProto.output_bytes', index=9, number=26, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='parameters', full_name='tensorflow.tfprof.GraphNodeProto.parameters', index=10, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='float_ops', full_name='tensorflow.tfprof.GraphNodeProto.float_ops', index=11, number=13, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='devices', full_name='tensorflow.tfprof.GraphNodeProto.devices', index=12, number=10, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_definition_count', full_name='tensorflow.tfprof.GraphNodeProto.total_definition_count', index=13, number=23, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_run_count', full_name='tensorflow.tfprof.GraphNodeProto.total_run_count', index=14, number=22, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_exec_micros', full_name='tensorflow.tfprof.GraphNodeProto.total_exec_micros', index=15, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_accelerator_exec_micros', full_name='tensorflow.tfprof.GraphNodeProto.total_accelerator_exec_micros', index=16, number=19, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_cpu_exec_micros', full_name='tensorflow.tfprof.GraphNodeProto.total_cpu_exec_micros', index=17, number=20, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_requested_bytes', full_name='tensorflow.tfprof.GraphNodeProto.total_requested_bytes', index=18, number=7, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_peak_bytes', full_name='tensorflow.tfprof.GraphNodeProto.total_peak_bytes', index=19, number=27, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_residual_bytes', full_name='tensorflow.tfprof.GraphNodeProto.total_residual_bytes', index=20, number=28, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_output_bytes', full_name='tensorflow.tfprof.GraphNodeProto.total_output_bytes', index=21, number=29, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_parameters', full_name='tensorflow.tfprof.GraphNodeProto.total_parameters', index=22, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_float_ops', full_name='tensorflow.tfprof.GraphNodeProto.total_float_ops', index=23, number=14, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shapes', full_name='tensorflow.tfprof.GraphNodeProto.shapes', index=24, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_shapes', full_name='tensorflow.tfprof.GraphNodeProto.input_shapes', index=25, number=16, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='children', full_name='tensorflow.tfprof.GraphNodeProto.children', index=26, number=12, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_GRAPHNODEPROTO_INPUTSHAPESENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=273, serialized_end=1183)
_MULTIGRAPHNODEPROTO = _descriptor.Descriptor(name='MultiGraphNodeProto', full_name='tensorflow.tfprof.MultiGraphNodeProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.tfprof.MultiGraphNodeProto.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='exec_micros', full_name='tensorflow.tfprof.MultiGraphNodeProto.exec_micros', index=1, number=2, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='accelerator_exec_micros', full_name='tensorflow.tfprof.MultiGraphNodeProto.accelerator_exec_micros', index=2, number=12, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='cpu_exec_micros', full_name='tensorflow.tfprof.MultiGraphNodeProto.cpu_exec_micros', index=3, number=13, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='requested_bytes', full_name='tensorflow.tfprof.MultiGraphNodeProto.requested_bytes', index=4, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='peak_bytes', full_name='tensorflow.tfprof.MultiGraphNodeProto.peak_bytes', index=5, number=16, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='residual_bytes', full_name='tensorflow.tfprof.MultiGraphNodeProto.residual_bytes', index=6, number=17, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_bytes', full_name='tensorflow.tfprof.MultiGraphNodeProto.output_bytes', index=7, number=18, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='parameters', full_name='tensorflow.tfprof.MultiGraphNodeProto.parameters', index=8, number=4, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='float_ops', full_name='tensorflow.tfprof.MultiGraphNodeProto.float_ops', index=9, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_exec_micros', full_name='tensorflow.tfprof.MultiGraphNodeProto.total_exec_micros', index=10, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_accelerator_exec_micros', full_name='tensorflow.tfprof.MultiGraphNodeProto.total_accelerator_exec_micros', index=11, number=14, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_cpu_exec_micros', full_name='tensorflow.tfprof.MultiGraphNodeProto.total_cpu_exec_micros', index=12, number=15, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_requested_bytes', full_name='tensorflow.tfprof.MultiGraphNodeProto.total_requested_bytes', index=13, number=7, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_peak_bytes', full_name='tensorflow.tfprof.MultiGraphNodeProto.total_peak_bytes', index=14, number=19, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_residual_bytes', full_name='tensorflow.tfprof.MultiGraphNodeProto.total_residual_bytes', index=15, number=20, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_output_bytes', full_name='tensorflow.tfprof.MultiGraphNodeProto.total_output_bytes', index=16, number=21, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_parameters', full_name='tensorflow.tfprof.MultiGraphNodeProto.total_parameters', index=17, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='total_float_ops', full_name='tensorflow.tfprof.MultiGraphNodeProto.total_float_ops', index=18, number=9, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_nodes', full_name='tensorflow.tfprof.MultiGraphNodeProto.graph_nodes', index=19, number=10, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='children', full_name='tensorflow.tfprof.MultiGraphNodeProto.children', index=20, number=11, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1186, serialized_end=1807)
_ADVICEPROTO_CHECKERSENTRY = _descriptor.Descriptor(name='CheckersEntry', full_name='tensorflow.tfprof.AdviceProto.CheckersEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.tfprof.AdviceProto.CheckersEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.tfprof.AdviceProto.CheckersEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1889, serialized_end=1976)
_ADVICEPROTO_CHECKER = _descriptor.Descriptor(name='Checker', full_name='tensorflow.tfprof.AdviceProto.Checker', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='reports', full_name='tensorflow.tfprof.AdviceProto.Checker.reports', index=0, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1978, serialized_end=2004)
_ADVICEPROTO = _descriptor.Descriptor(name='AdviceProto', full_name='tensorflow.tfprof.AdviceProto', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='checkers', full_name='tensorflow.tfprof.AdviceProto.checkers', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_ADVICEPROTO_CHECKERSENTRY, _ADVICEPROTO_CHECKER], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1810, serialized_end=2004)
_TFPROFTENSORPROTO.fields_by_name['dtype'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_GRAPHNODEPROTO_INPUTSHAPESENTRY.fields_by_name['value'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_GRAPHNODEPROTO_INPUTSHAPESENTRY.containing_type = _GRAPHNODEPROTO
_GRAPHNODEPROTO.fields_by_name['tensor_value'].message_type = _TFPROFTENSORPROTO
_GRAPHNODEPROTO.fields_by_name['shapes'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__shape__pb2._TENSORSHAPEPROTO
_GRAPHNODEPROTO.fields_by_name['input_shapes'].message_type = _GRAPHNODEPROTO_INPUTSHAPESENTRY
_GRAPHNODEPROTO.fields_by_name['children'].message_type = _GRAPHNODEPROTO
_MULTIGRAPHNODEPROTO.fields_by_name['graph_nodes'].message_type = _GRAPHNODEPROTO
_MULTIGRAPHNODEPROTO.fields_by_name['children'].message_type = _MULTIGRAPHNODEPROTO
_ADVICEPROTO_CHECKERSENTRY.fields_by_name['value'].message_type = _ADVICEPROTO_CHECKER
_ADVICEPROTO_CHECKERSENTRY.containing_type = _ADVICEPROTO
_ADVICEPROTO_CHECKER.containing_type = _ADVICEPROTO
_ADVICEPROTO.fields_by_name['checkers'].message_type = _ADVICEPROTO_CHECKERSENTRY
DESCRIPTOR.message_types_by_name['TFProfTensorProto'] = _TFPROFTENSORPROTO
DESCRIPTOR.message_types_by_name['GraphNodeProto'] = _GRAPHNODEPROTO
DESCRIPTOR.message_types_by_name['MultiGraphNodeProto'] = _MULTIGRAPHNODEPROTO
DESCRIPTOR.message_types_by_name['AdviceProto'] = _ADVICEPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
TFProfTensorProto = _reflection.GeneratedProtocolMessageType('TFProfTensorProto', (_message.Message,), {'DESCRIPTOR': _TFPROFTENSORPROTO, '__module__': 'tensorflow.core.profiler.tfprof_output_pb2'})
_sym_db.RegisterMessage(TFProfTensorProto)
GraphNodeProto = _reflection.GeneratedProtocolMessageType('GraphNodeProto', (_message.Message,), {'InputShapesEntry': _reflection.GeneratedProtocolMessageType('InputShapesEntry', (_message.Message,), {'DESCRIPTOR': _GRAPHNODEPROTO_INPUTSHAPESENTRY, '__module__': 'tensorflow.core.profiler.tfprof_output_pb2'}), 'DESCRIPTOR': _GRAPHNODEPROTO, '__module__': 'tensorflow.core.profiler.tfprof_output_pb2'})
_sym_db.RegisterMessage(GraphNodeProto)
_sym_db.RegisterMessage(GraphNodeProto.InputShapesEntry)
MultiGraphNodeProto = _reflection.GeneratedProtocolMessageType('MultiGraphNodeProto', (_message.Message,), {'DESCRIPTOR': _MULTIGRAPHNODEPROTO, '__module__': 'tensorflow.core.profiler.tfprof_output_pb2'})
_sym_db.RegisterMessage(MultiGraphNodeProto)
AdviceProto = _reflection.GeneratedProtocolMessageType('AdviceProto', (_message.Message,), {'CheckersEntry': _reflection.GeneratedProtocolMessageType('CheckersEntry', (_message.Message,), {'DESCRIPTOR': _ADVICEPROTO_CHECKERSENTRY, '__module__': 'tensorflow.core.profiler.tfprof_output_pb2'}), 'Checker': _reflection.GeneratedProtocolMessageType('Checker', (_message.Message,), {'DESCRIPTOR': _ADVICEPROTO_CHECKER, '__module__': 'tensorflow.core.profiler.tfprof_output_pb2'}), 'DESCRIPTOR': _ADVICEPROTO, '__module__': 'tensorflow.core.profiler.tfprof_output_pb2'})
_sym_db.RegisterMessage(AdviceProto)
_sym_db.RegisterMessage(AdviceProto.CheckersEntry)
_sym_db.RegisterMessage(AdviceProto.Checker)
_GRAPHNODEPROTO_INPUTSHAPESENTRY._options = None
_ADVICEPROTO_CHECKERSENTRY._options = None



# /* Copyright 2019 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================*/
#
# #include <Python.h>
#
# #include <array>
#
# #include "pybind11/pybind11.h"
# #include "pybind11/pytypes.h"
# #include "tensorflow/python/lib/core/py_exception_registry.h"
from .lib.core import py_exception_registry
#
# namespace py = pybind11;
#
# PYBIND11_MODULE(_pywrap_py_exception_registry, m) {
#   m.def("PyExceptionRegistry_Init", [](py::object& code_to_exc_type_map) {
#     tensorflow::PyExceptionRegistry::Init(code_to_exc_type_map.ptr());
#   });
def PyExceptionRegistry_Init(code_to_exc_type_map: dict):
  return py_exception_registry.PyExceptionRegistry.Init(code_to_exc_type_map)
#   m.def("PyExceptionRegistry_Lookup",
#         [](TF_Code code) { tensorflow::PyExceptionRegistry::Lookup(code); });
def PyExceptionRegistry_Lookup(code):
  return py_exception_registry.PyExceptionRegistry.Lookup(code)

# };




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ......tensorflow.compiler.xla import xla_data_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xla/service/gpu/backend_configs.proto', package='xla.gpu', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n9tensorflow/compiler/xla/service/gpu/backend_configs.proto\x12\x07xla.gpu\x1a&tensorflow/compiler/xla/xla_data.proto"\x95\x01\n\x16CudnnConvBackendConfig\x12\x11\n\talgorithm\x18\x01 \x01(\x03\x12\x1a\n\x12tensor_ops_enabled\x18\x02 \x01(\x08\x12\x19\n\x11conv_result_scale\x18\x04 \x01(\x01\x12\x17\n\x0factivation_mode\x18\x03 \x01(\x03\x12\x18\n\x10side_input_scale\x18\x05 \x01(\x01"\xc1\x01\n\x11GemmBackendConfig\x12\x1c\n\x12selected_algorithm\x18\x01 \x01(\x03H\x00\x12\x12\n\nalpha_real\x18\x02 \x01(\x01\x12\x12\n\nalpha_imag\x18\t \x01(\x01\x12\x0c\n\x04beta\x18\x03 \x01(\x01\x127\n\x15dot_dimension_numbers\x18\x07 \x01(\x0b2\x18.xla.DotDimensionNumbers\x12\x12\n\nbatch_size\x18\x08 \x01(\x03B\x0b\n\talgorithm"h\n\x14BitcastBackendConfig\x12\'\n\rsource_layout\x18\x01 \x01(\x0b2\x10.xla.LayoutProto\x12\'\n\rresult_layout\x18\x02 \x01(\x0b2\x10.xla.LayoutProtob\x06proto3', dependencies=[tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2.DESCRIPTOR])
_CUDNNCONVBACKENDCONFIG = _descriptor.Descriptor(name='CudnnConvBackendConfig', full_name='xla.gpu.CudnnConvBackendConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='algorithm', full_name='xla.gpu.CudnnConvBackendConfig.algorithm', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor_ops_enabled', full_name='xla.gpu.CudnnConvBackendConfig.tensor_ops_enabled', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='conv_result_scale', full_name='xla.gpu.CudnnConvBackendConfig.conv_result_scale', index=2, number=4, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='activation_mode', full_name='xla.gpu.CudnnConvBackendConfig.activation_mode', index=3, number=3, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='side_input_scale', full_name='xla.gpu.CudnnConvBackendConfig.side_input_scale', index=4, number=5, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=111, serialized_end=260)
_GEMMBACKENDCONFIG = _descriptor.Descriptor(name='GemmBackendConfig', full_name='xla.gpu.GemmBackendConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='selected_algorithm', full_name='xla.gpu.GemmBackendConfig.selected_algorithm', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='alpha_real', full_name='xla.gpu.GemmBackendConfig.alpha_real', index=1, number=2, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='alpha_imag', full_name='xla.gpu.GemmBackendConfig.alpha_imag', index=2, number=9, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='beta', full_name='xla.gpu.GemmBackendConfig.beta', index=3, number=3, type=1, cpp_type=5, label=1, has_default_value=False, default_value=float(0), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dot_dimension_numbers', full_name='xla.gpu.GemmBackendConfig.dot_dimension_numbers', index=4, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='batch_size', full_name='xla.gpu.GemmBackendConfig.batch_size', index=5, number=8, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='algorithm', full_name='xla.gpu.GemmBackendConfig.algorithm', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=263, serialized_end=456)
_BITCASTBACKENDCONFIG = _descriptor.Descriptor(name='BitcastBackendConfig', full_name='xla.gpu.BitcastBackendConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='source_layout', full_name='xla.gpu.BitcastBackendConfig.source_layout', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='result_layout', full_name='xla.gpu.BitcastBackendConfig.result_layout', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=458, serialized_end=562)
_GEMMBACKENDCONFIG.fields_by_name['dot_dimension_numbers'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._DOTDIMENSIONNUMBERS
_GEMMBACKENDCONFIG.oneofs_by_name['algorithm'].fields.append(_GEMMBACKENDCONFIG.fields_by_name['selected_algorithm'])
_GEMMBACKENDCONFIG.fields_by_name['selected_algorithm'].containing_oneof = _GEMMBACKENDCONFIG.oneofs_by_name['algorithm']
_BITCASTBACKENDCONFIG.fields_by_name['source_layout'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._LAYOUTPROTO
_BITCASTBACKENDCONFIG.fields_by_name['result_layout'].message_type = tensorflow_dot_compiler_dot_xla_dot_xla__data__pb2._LAYOUTPROTO
DESCRIPTOR.message_types_by_name['CudnnConvBackendConfig'] = _CUDNNCONVBACKENDCONFIG
DESCRIPTOR.message_types_by_name['GemmBackendConfig'] = _GEMMBACKENDCONFIG
DESCRIPTOR.message_types_by_name['BitcastBackendConfig'] = _BITCASTBACKENDCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
CudnnConvBackendConfig = _reflection.GeneratedProtocolMessageType('CudnnConvBackendConfig', (_message.Message,), {'DESCRIPTOR': _CUDNNCONVBACKENDCONFIG, '__module__': 'tensorflow.compiler.xla.service.gpu.backend_configs_pb2'})
_sym_db.RegisterMessage(CudnnConvBackendConfig)
GemmBackendConfig = _reflection.GeneratedProtocolMessageType('GemmBackendConfig', (_message.Message,), {'DESCRIPTOR': _GEMMBACKENDCONFIG, '__module__': 'tensorflow.compiler.xla.service.gpu.backend_configs_pb2'})
_sym_db.RegisterMessage(GemmBackendConfig)
BitcastBackendConfig = _reflection.GeneratedProtocolMessageType('BitcastBackendConfig', (_message.Message,), {'DESCRIPTOR': _BITCASTBACKENDCONFIG, '__module__': 'tensorflow.compiler.xla.service.gpu.backend_configs_pb2'})
_sym_db.RegisterMessage(BitcastBackendConfig)
